Module pumpfun

Module pumpfun 

Structs

CurveState
Zero-copy view over the bonding-curve account bytes.
PumpFun

Constants

BONDING_CURVE_DISCRIMINATOR
BUY_DISCRIMINATOR
EVENT_AUTHORITY
FEE_CONFIG
FEE_PROGRAM
FEE_RECIPIENT
GLOBAL_ACCOUNT
GLOBAL_VOLUME_ACCUMULATOR
MAYHEM_FEE_RECIPIENTS
Mayhem mode fee recipients from PumpFun global.reserved_fee_recipient and global.reserved_fee_recipients. When BondingCurve::is_mayhem_mode is true, account index 1 (fee_recipient) must be one of these.
PROGRAM_ID
PROTOCOL_EXTRA_FEE_RECIPIENTS
Apr 2026 protocol upgrade: one of these eight addresses is appended, writable, after bonding_curve_v2 on every buy/sell. Any of the eight is accepted by the fee program; we use index 0 deterministically. See https://github.com/pump-fun/pump-public-docs/blob/main/docs/BREAKING_FEE_RECIPIENT.md.
SELL_DISCRIMINATOR

Functions

_global_volume_accumulator_pda
bonding_curve_pda
bonding_curve_v2_pda
creator_vault_pda
user_volume_accumulator_pda